@@ -1,19 +1,22 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
 import re
 
-from lib.core.common import decodeHex
+from lib.core.common import singleTimeWarnMessage
+from lib.core.convert import decodeHex
+from lib.core.convert import getOrds
+from lib.core.enums import DBMS
 from lib.core.enums import PRIORITY
 
 __priority__ = PRIORITY.NORMAL
 
 def dependencies():
-    pass
+    singleTimeWarnMessage("tamper script '%s' is only meant to be run against %s" % (os.path.basename(__file__).split(".")[0], DBMS.MYSQL))
 
 def tamper(payload, **kwargs):
     """
@@ -37,7 +40,7 @@ def tamper(payload, **kwargs):
     if payload:
         for match in re.finditer(r"\b0x([0-9a-f]+)\b", retVal):
             if len(match.group(1)) > 2:
-                result = "CONCAT(%s)" % ','.join("CHAR(%d)" % ord(_) for _ in decodeHex(match.group(1)))
+                result = "CONCAT(%s)" % ','.join("CHAR(%d)" % _ for _ in getOrds(decodeHex(match.group(1))))
             else:
                 result = "CHAR(%d)" % ord(decodeHex(match.group(1)))
             retVal = retVal.replace(match.group(0), result)
